create_map: Create map

Description Usage Arguments

View source: R/create_map.R

Description

Fetch a map of Groningen from OpenStreetMap and save it as a PNG-file.

Usage

1
2
3
4
5
6
7
8
create_map(
  png_filename,
  show_bridge_openings = "yes",
  right_lon = 1,
  left_lon = 2,
  top_lat = 3,
  bottom_lat = 4
)

Arguments

png_filename

name of the PNG that the map will be saved to

show_bridge_openings

character string indicating whether or not bridge openings are plotted on top of the basemap. The default, "yes" adds the real time bridge openings to the map. "fake" adds one fake bridge opening in the center of Groningen. "no" does not add any bridge openings to the map.

right_lon

right longitude

left_lon

left longitude

top_lat

top latitude

bottom_lat

bottom latitude


informalr/informalr documentation built on June 19, 2021, 8:26 p.m.