create_map_car_densities: Create a map of Groningen with car densities.

Description Usage Arguments

View source: R/create_map_measurements.R

Description

Fetch a map of Groningen and plot the densities of cars in the area using the data from the Dutch government.

Usage

1
create_map_car_densities(png_filename, show_measurements = TRUE)

Arguments

png_filename

name of the PNG that the map will be saved to

show_measurements

plot measurements on the map YES/NO?


informalr/informalr documentation built on June 19, 2021, 8:26 p.m.