power_two_numbers: Give the power of one number to the second one

Description Usage Arguments Value Author(s) Examples

View source: R/power_two_numbers.R

Description

Give the power of one number to the second one

Usage

1

Arguments

a

A number

b

A number

Value

Number A to the power of number B

Author(s)

Jan Derk Kotlarski

Examples

1

informalr/informalr documentation built on June 19, 2021, 8:26 p.m.