Fetch a map of Groningen from OpenStreetMap and save it as a PNG-file.
1 2 3 4 5 6 7 8 | create_map(
png_filename,
show_bridge_openings = "yes",
right_lon = 1,
left_lon = 2,
top_lat = 3,
bottom_lat = 4
)
|
png_filename |
name of the PNG that the map will be saved to |
show_bridge_openings |
character string indicating whether or not
bridge openings are plotted on top of the basemap. The default,
|
right_lon |
right longitude |
left_lon |
left longitude |
top_lat |
top latitude |
bottom_lat |
bottom latitude |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.