View source: R/create_map_measurements.R
Fetch a map of Groningen and plot the densities of cars in the area using the data from the Dutch government.
1 | create_map_car_densities(png_filename, show_measurements = TRUE)
|
png_filename |
name of the PNG that the map will be saved to |
show_measurements |
plot measurements on the map YES/NO? |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.